
*******************************************************************
***************** BASELINE GREENBOOK FORECASTS ********************
*******************************************************************


*ESTIMATE THE TAYLOR RULE FOR THE US AGGREGATE (SAME REACTION FUNCTION FOR ALL STATES)
clear
use US_data
tsset time
set more off

gen US_dur0 = d.US_ur0 
gen spf_dur = d.spf_ur 
sum US_dur0 spf_dur 


*Estimated Taylor rule
foreach v in intr cpi slack gdp cons{
	gen beta_`v'= .
}
gen yfit = .
gen resid = .
gen r_star = .

newey intr l(1/1).intr US_cpi_favg US_og0 US_grgdp0 if tin(1984q1,2007q4), lag(2)
predict y, xb
predict e, resid
replace yfit=y
replace resid=e
drop y e
replace beta_intr = _b[l1.intr]
replace beta_cpi = _b[US_cpi_favg]
replace beta_slack = _b[US_og0]
replace beta_gdp = _b[US_grgdp0]
replace beta_cons = _b[_cons]
replace r_star = beta_cons-2*(1-beta_cpi)

*Greenbook forecasts only go up to 2011q4
*Assumption: use SPF forecasts to extend the yfit of the Taylor rule up to 2017q4
replace yfit = beta_cons + beta_intr*l1.intr + beta_cpi*spf_cpi_favg + beta_slack*spf_og + beta_gdp*spf_grgdp if time>=tq(2012q1)


*FIGURE 4 in the paper: FITTED VALUES OF THE US TAYLOR VS FED FUNDS
gen min=-3 if tin(2007q4,2017q4)
gen max=12 if tin(2007q4,2017q4)

set scheme s1mono
twoway (area min max time if tin(1984q1,2017q4), bcolor(gs15 gs15) ysc(r(-3 12))) (line intr yfit time if tin(1984q1,2017q4), yline(0) yla(-3(3)12) ///
legend(order(3 "Fed funds" 4 "Taylor rule")) legend(pos(7) ring(0) col(2)) color(navy cranberry green) lpattern(solid dash) ///
ytitle(%) xtitle("") xla(97(19)231))

keep(time state statenr intr* yfit resid beta* r_star)
saveold Tay_base, version(12) replace



*US STATES

clear
use States_data
xtset statenr time

*Merge with US data
capture merge m:1 time using Tay_base, assert(match master) keep(match master)
drop _merge

xtset statenr time
gen cpi_favg_yoy = (f1.cpi_yoy+f2.cpi_yoy)/2

*Apply US coefficients
xtset statenr time
by statenr: gen yfit_state = beta_cons + beta_intr*l1.intr + beta_cpi*cpi_favg_yoy + beta_slack*ogap_ham + beta_gdp*dlrgdp if tin(1984q1,2017q4)

*Compute deviation from fitted values
by statenr: gen mpsg = (yfit_state- yfit) if tin(1984q1,2017q4)
sum mpsg

*Interquartile range
*4-quarter centered moving average
bys time: egen yfit_state_iqr=iqr(yfit_state)
xtset statenr time
gen yfit_state_iqr4q = (F1.yfit_state_iqr + yfit_state_iqr + L1.yfit_state_iqr + L2.yfit_state_iqr) / 4

*Figure 5 in the paper 
twoway line yfit_state_iqr4q time if tin(1999q4,2017q2) & statenr==1, legend(off) ytitle(percentage points) yla(0.2(0.1)0.6) xtitle("") xla(159(10)229) graphregion(fcolor(white)) color(navy) name(dispersion, replace) 



*Purge MPSG from current state of the economy a la Bassett et al. (2014)
gen mpsg_exo = .
forval i=1/50{
	capture newey mpsg cpi_yoy dlrgdp tdebtinc_gap dlrhw_sa if statenr==`i' & tin(1999q1,2017q4), lag(2)
	capture predict e, resid
	capture replace mpsg_exo = e if statenr==`i'
}
sum mpsg mpsg_exo
correl mpsg mpsg_exo


*Go to 3_LP.do file to run local projections

**************************************************************************************************************************************************************************************



*********************************************************
***************** WU-XIA SHADOW RATE ********************
*********************************************************

clear
use US_data
tsset time
set more off

*Estimated Taylor rule
foreach v in intr cpi slack gdp cons{
	gen beta_`v'= .
}
gen yfit = .
gen resid = .
gen r_star = .

newey wu_xia l(1/1).wu_xia cpi_favg_greenspf og_greenspf grgdp_greenspf if tin(1984q1,2017q4), lag(2)
predict y, xb
predict e, resid
replace yfit=y
replace resid=e
drop y e
replace beta_intr = _b[l1.wu_xia]
replace beta_cpi = _b[cpi_favg_greenspf]
replace beta_slack = _b[og_greenspf]
replace beta_gdp = _b[grgdp_greenspf]
replace beta_cons = _b[_cons]
replace r_star = beta_cons-2*(1-beta_cpi)


keep(time state statenr intr* wu_xia* yfit resid beta* r_star)
saveold Tay_wuxia, version(12) replace



*US STATES

clear
use States_data
xtset statenr time

*Merge with US data
capture merge m:1 time using Tay_wuxia, assert(match master) keep(match master)
drop _merge

xtset statenr time
gen cpi_favg_yoy = (f1.cpi_yoy+f2.cpi_yoy)/2

*Apply US coefficients
xtset statenr time
by statenr: gen yfit_state = beta_cons + beta_intr*l1.wu_xia + beta_cpi*cpi_favg_yoy + beta_slack*ogap_ham + beta_gdp*dlrgdp if tin(1984q1,2017q4)

*Compute deviation from fitted values
by statenr: gen mpsg = (yfit_state- yfit) if tin(1984q1,2017q4)
sum mpsg

*Interquartile range
bys time: egen yfit_state_iqr=iqr(yfit_state)

*4-quarter centered moving average
xtset statenr time
gen yfit_state_iqr4q = (F1.yfit_state_iqr + yfit_state_iqr + L1.yfit_state_iqr + L2.yfit_state_iqr) / 4


*Go to 4_LP_robust.do file to run local projections


**************************************************************************************************************************************************************************************


*****************************************************
***************** FINANCIAL CYCLE *******************
*****************************************************

clear
use US_data
tsset time
set more off

*DEBT GAP
foreach v in tdebt mdebt{
	gen US_`v'inc = US_`v'/US_income*100
}
	
*New method by Hamilton (2018, RESTAT)
*Hamilton suggests h=20 for the debt cycle if the data are reasonably long
foreach v in US_tdebtinc US_mdebtinc{
	reg f20.`v' l(0/3).`v', robust 
	predict yfit, xb
	predict e, resid
	gen trend_`v'_ham = l20.yfit 
	gen cycle_`v'_ham = l20.e
	drop yfit e
}

rename cycle_US_tdebtinc_ham US_tdebtinc_gap 
rename cycle_US_mdebtinc_ham US_mdebtinc_gap 


*Estimated Taylor rule
foreach v in intr cpi slack gdp cons debtgap{
	gen beta_`v'= .
}
gen yfit = .
gen resid = .
gen r_star = .

newey wu_xia l(1/1).wu_xia cpi_favg_greenspf og_greenspf grgdp_greenspf US_tdebtinc_gap if tin(1984q1,2017q4), lag(2)
predict y, xb
predict e, resid
replace yfit=y
replace resid=e
drop y e
replace beta_intr = _b[l1.wu_xia]
replace beta_cpi = _b[cpi_favg_greenspf]
replace beta_slack = _b[og_greenspf]
replace beta_gdp = _b[grgdp_greenspf]
replace beta_cons = _b[_cons]
replace beta_debtgap = _b[US_tdebtinc_gap]
replace r_star = beta_cons-2*(1-beta_cpi)

keep(time state statenr intr* wu_xia* yfit resid beta* r_star)
saveold Tay_fin, version(12) replace



*US STATES
clear
use States_data
xtset statenr time

*Merge with US data
capture merge m:1 time using Tay_fin, assert(match master) keep(match master)
drop _merge

xtset statenr time
gen cpi_favg_yoy = (f1.cpi_yoy+f2.cpi_yoy)/2

*Apply US coefficients
xtset statenr time
by statenr: gen yfit_state = beta_cons + beta_intr*l1.wu_xia + beta_cpi*cpi_favg_yoy + beta_slack*ogap_ham + beta_gdp*dlrgdp + beta_debtgap*tdebtinc_gap if tin(1984q1,2017q4)

*Compute deviation from fitted values
by statenr: gen mpsg = (yfit_state- yfit) if tin(1984q1,2017q4)
sum mpsg

*Interquartile range
bys time: egen yfit_state_iqr=iqr(yfit_state)

*4-quarter centered moving average
xtset statenr time
gen yfit_state_iqr4q = (F1.yfit_state_iqr + yfit_state_iqr + L1.yfit_state_iqr + L2.yfit_state_iqr) / 4


*Go to 4_LP_robust.do file to run local projections

**************************************************************************************************************************************************************************************



********************************************************
***************** UNEMPLOYMENT GAP *********************
********************************************************

clear
use US_data
tsset time
set more off

*Estimated Taylor rule
foreach v in intr cpi slack gdp cons{
	gen beta_`v'= .
}
gen yfit = .
gen resid = .
gen r_star = .

newey intr l(1/1).intr US_cpi_favg US_ugap0 US_grgdp0 if tin(1984q1,2007q4), lag(2)
predict y, xb
predict e, resid
replace yfit=y
replace resid=e
drop y e
replace beta_intr = _b[l1.intr]
replace beta_cpi = _b[US_cpi_favg]
replace beta_slack = _b[US_ugap0]
replace beta_gdp = _b[US_grgdp0]
replace beta_cons = _b[_cons]
replace r_star = beta_cons-2*(1-beta_cpi)

*Greenbook forecasts only go up to 2011q4
*Assumption: use SPF forecasts to extend the yfit of the Taylor rule up to 2017q4
replace yfit = beta_cons + beta_intr*l1.intr + beta_cpi*spf_cpi_favg + beta_slack*spf_ugap + beta_gdp*spf_grgdp if time>=tq(2012q1)

keep(time state statenr intr* yfit resid beta* r_star)
saveold Tay_ugap, version(12) replace


*US STATES
clear
use States_data
xtset statenr time

*Merge with US data
capture merge m:1 time using Tay_ugap, assert(match master) keep(match master)
drop _merge

xtset statenr time
gen cpi_favg_yoy = (f1.cpi_yoy+f2.cpi_yoy)/2

*Apply US coefficients
xtset statenr time
by statenr: gen yfit_state = beta_cons + beta_intr*l1.intr + beta_cpi*cpi_favg_yoy + beta_slack*ugap_ham + beta_gdp*dlrgdp if tin(1984q1,2017q4)

*Compute deviation from fitted values
by statenr: gen mpsg = (yfit_state- yfit) if tin(1984q1,2017q4)
sum mpsg

*Interquartile range
bys time: egen yfit_state_iqr=iqr(yfit_state)

*4-quarter centered moving average
xtset statenr time
gen yfit_state_iqr4q = (F1.yfit_state_iqr + yfit_state_iqr + L1.yfit_state_iqr + L2.yfit_state_iqr) / 4


*Go to 4_LP_robust.do file to run local projections


**************************************************************************************************************************************************************************************


********************************************************
***************** ACTUAL DATA **************************
********************************************************

clear
use US_data
tsset time
set more off

*Estimated Taylor rule
foreach v in intr cpi slack gdp cons{
	gen beta_`v'= .
}
gen yfit = .
gen resid = .
gen r_star = .

newey intr l(1/1).intr US_cpi_yoy US_ugap if tin(1984q1,2007q4), lag(2)
predict y, xb
predict e, resid
replace yfit=y
replace resid=e
drop y e
replace beta_intr = _b[l1.intr]
replace beta_cpi = _b[US_cpi_yoy]
replace beta_slack = _b[US_ugap]
replace beta_cons = _b[_cons]
replace r_star = beta_cons-2*(1-beta_cpi)

keep(time state statenr intr* yfit resid beta* r_star)
saveold Tay_dat, version(12) replace



*US STATES
clear
use States_data
xtset statenr time

*Merge with US data
capture merge m:1 time using Tay_dat, assert(match master) keep(match master)
drop _merge

*Apply US coefficients
xtset statenr time
by statenr: gen yfit_state = beta_cons + beta_intr*l1.intr + beta_cpi*cpi_yoy + beta_slack*ugap_ham if tin(1984q1,2017q4)

*Compute deviation from fitted values
by statenr: gen mpsg = (yfit_state- yfit) if tin(1984q1,2017q4)
sum mpsg

*Interquartile range
bys time: egen yfit_state_iqr=iqr(yfit_state)

*4-quarter centered moving average
xtset statenr time
gen yfit_state_iqr4q = (F1.yfit_state_iqr + yfit_state_iqr + L1.yfit_state_iqr + L2.yfit_state_iqr) / 4


*Go to 4_4_LP_robust.do file to run local projections

**************************************************************************************************************************************************************************************
