
*LOCAL PROJECTIONS

label variable tdebtinc "Debt-to-income"
label variable lrgdp "GDP"
label variable hpinc_sa "House prices"
label variable lrhpi_sa "House prices"
label variable lrhw_sa "Housing wealth"
label variable homeown_sa "Homeownership rate"
label variable cpi "Inflation"
label variable lrpce "PCE"
label variable lrpce_dur "PCE: durables"
label variable lrpce_ndur "PCE: non-durables"
label variable lrpce_serv "PCE: services"
label variable lrpce_dsv "PCE: dur. & serv."

bysort statenr: gen dtdebtinc_gap = d.tdebtinc_gap

*h is the horizon
bysort statenr (time): gen h = _n-95 if time>=tq(1999q3)
sum h

foreach v in coef coefu coefl{
foreach p in tdebtinc tdebtinc_gap lrtdebt lrgdp lrgdp_pc lrpce lrpce_dur lrpce_ndur lrpce_serv lrpce_dsv hpinc_sa lrhpi_sa lrhw_sa cpi mpsg mpsg_exo homeown_sa{
	gen `v'_`p' =.
}
}

*Cumulative growth
foreach v in tdebtinc tdebtinc_gap hpinc_sa mpsg homeown_sa{
forval i= 1/21 {
	by statenr: gen d`i'`v'_cum = F`i'.`v' - F1.`v'
}
}

foreach v in lrgdp lrgdp_pc lrpce lrpce_dur lrpce_ndur lrpce_serv lrpce_dsv lrtdebt lrhpi_sa lrhw_sa{
forval i= 1/21 {
	by statenr: gen d`i'`v'_cum = (F`i'.`v' - F1.`v')*100
}
}

forval i= 1/21 {
	by statenr: gen d`i'cpi_cum = (F`i'.lcpi-F1.lcpi)*100
}

*Rename h to be consistent with the IRF charts
foreach v in tdebtinc tdebtinc_gap hpinc_sa lrgdp lrgdp_pc lrpce lrpce_dur lrpce_ndur lrpce_serv lrpce_dsv lrtdebt lrhpi_sa lrhw_sa cpi mpsg homeown_sa{
forval i= 1/21{
local j = `i'-1
	rename d`i'`v'_cum d`j'`v'_cum
}
}

*1-std deviation change
sum mpsg if tin(1999q1,2017q4)
gen std_mpsg=r(sd)



*DEFINING HIGH VS LOW DEBT PERIODS

*Time series (quintiles)
egen debt_q = xtile(tdebtinc_gap) if tin(1999q1,2017q4), by(statenr) nq(5)
tab debt_q if time>=tq(1999q1)

*Define high vs low (lagged one period to control for endogeneity)
foreach v in h l m{
	gen debt_`v' = 0
}
replace debt_h = 1 if l1.debt_q==5
replace debt_l = 1 if l1.debt_q==1
replace debt_m = 1 if inlist(l1.debt_q,2,3,4)
tab debt_h debt_l if tin(1999q1,2017q4)
tab debt_h debt_m if tin(1999q1,2017q4)


xtset statenr time 
foreach var in lrgdp dlrgdp lrpce lrpce_dur lrpce_ndur lrpce_serv lrpce_dsv dlrpce dlrpce_dur dlrpce_ndur dlrpce_serv dlrpce_dsv tdebtinc dlrtdebt mpsg mpsg_exo lrgdp_pc ///
hpinc_sa lrhw_sa dlrhw_sa dlcpi cpi dtdebtinc dtdebtinc_gap dlrhpi_sa dhomeown_sa dur dhpinc_sa dintrcm dltv dforecl dlrincome_pc{ 
foreach debt in debt_h debt_l debt_m { 
	gen `var'_`debt' = `var'*`debt' 
}
}

foreach v in coef coefu coefl {
foreach w in tdebtinc tdebtinc_gap lrtdebt lrgdp lrgdp_pc lrpce lrpce_dur lrpce_ndur lrpce_serv lrpce_dsv dlrpce dlrpce_dur dlrpce_ndur dlrpce_serv dlrpce_dsv hpinc_sa ///
lrhpi_sa lrhw_sa cpi mpsg mpsg_exo homeown_sa{
foreach debt in debt_h debt_l debt_m { 
	gen `v'_`w'_`debt' =.
}
}
}


	
*RECESSIONS/SLACK

foreach r in gdpma_r gdp_r ogap_r ugap_r{
	gen `r' = 0
}

*State-specififc recession dummy - 20% of sample according to 1st quintile of 3-quarter moving average (similar to Tenreyro and Thwaites, 2016)
bysort statenr: gen dlrgdp_ma = (dlrgdp + l1.dlrgdp + l2.dlrgdp)/3 
egen dlrgdp_ma_q = xtile(dlrgdp_ma) if tin(1999q1,2017q3), by(statenr) nq(5)
tab dlrgdp_ma_q if time>=tq(1999q1)
by statenr: replace gdpma_r = 1 if l1.dlrgdp_ma_q==1 
tab gdpma_r if tin(1999q1,2017q3)
bysort gdpma_r: sum ogap_ham if tin(1999q1,2017q3)

*2 consecutive declines in real GDP
xtset statenr time 
by statenr: replace gdp_r = 1 if l1.dlrgdp<0 & l2.dlrgdp<0

*Negative output gap or positive ugap
xtset statenr time 
by statenr: replace ogap_r = 1 if ogap_ham<0
by statenr: replace ugap_r = 1 if ugap_ham>0
tab ogap_r ugap_r if tin(1999q1,2017q4)


xtset statenr time 
foreach var in lrgdp dlrgdp lrpce lrpce_dur lrpce_ndur lrpce_serv lrpce_dsv dlrpce dlrpce_dur dlrpce_ndur dlrpce_serv dlrpce_dsv tdebtinc dlrtdebt mpsg mpsg_exo lrgdp_pc ///
hpinc_sa lrhw_sa dlrhw_sa dlcpi cpi dtdebtinc dtdebtinc_gap dlrhpi_sa dhomeown_sa { 
foreach recess in gdpma_r gdp_r ogap_r ugap_r { 
	gen `var'_`recess' = `var'*`recess' 
}
}

foreach v in coef coefu coefl {
foreach w in tdebtinc tdebtinc_gap lrtdebt lrgdp lrgdp_pc lrpce lrpce_dur lrpce_ndur lrpce_serv lrpce_dsv hpinc_sa lrhpi_sa lrhw_sa cpi homeown_sa{
foreach recess in gdpma_r gdp_r ogap_r ugap_r { 
	gen `v'_`w'_`recess' =.
}
}
}

xtset statenr time 
foreach var in lrgdp dlrgdp lrgdp_pc lrpce lrpce_dur lrpce_ndur lrpce_serv lrpce_dsv dlrpce dlrpce_dur dlrpce_ndur dlrpce_serv dlrpce_dsv tdebtinc lrtdebt mpsg mpsg_exo ///
hpinc_sa lrhw_sa dlrhw_sa dlcpi cpi dtdebtinc dtdebtinc_gap dlrhpi_sa dhomeown_sa dur dlrincome_pc{ 
foreach debt in debt_h debt_l debt_m { 
foreach recess in gdpma_r gdp_r ogap_r ugap_r {
	gen `var'_`recess'_`debt' = `var'*`recess'*`debt'
}
}
}

foreach v in coef coefu coefl {
foreach w in tdebtinc lrtdebt lrgdp lrgdp_pc lrpce lrpce_dur lrpce_ndur lrpce_serv lrpce_dsv hpinc_sa lrhpi_sa lrhw_sa cpi homeown_sa{
foreach debt in debt_h debt_l debt_m { 
foreach recess in gdpma_r gdp_r ogap_r ugap_r {
	gen `v'_`w'_`recess'_`debt' =.
}
}
}
}

*Start estimation from 1999q1
drop if tin(1976q1,1998q4)

*For xtivreg2 I need to create the time dummies!
tabulate time, generate(time_dum)

***************************************************************************************************************************************************************************************

*DISTRIBUTION OF DEBT GAP PERIODS OVER TIME
foreach v in h l m {
	bysort time: egen count_debt_`v' = count(debt_`v') if debt_`v'==1
}

*Replace msssing values in a sequence
*Forward
sort time
foreach v in h l m {
	bysort time: carryforward count_debt_`v', replace
}
*Backwards
gen int negtime = -time
foreach v in h l m {
	bysort negtime: carryforward count_debt_`v', replace back
}
drop negtime

tabstat count_debt_h, stat(mean) by(time)
egen count_N= rowtotal(count_debt_h count_debt_l count_debt_m),missing
sum count_N

foreach v in h l m {
	bysort time: gen count_debt_`v'_shr = count_debt_`v'/count_N
}


foreach v in h l m {
	replace count_debt_`v' = 0 if missing(count_debt_`v')
	replace count_debt_`v'_shr = 0 if missing(count_debt_`v'_shr)
}


*Figure B.16 in the paper
gen A = count_debt_h_shr
egen B = rowtotal(count_debt_h_shr count_debt_l_shr),missing
set scheme s1mono
twoway bar A time if time>=tq(2002q1), color(cranberry) || rbar A B time if time>=tq(2002q1), graphregion(fcolor(white)) ///
legend(label(1 "High") label(2 "Low")) xtitle(" ") ytitle("Frequency") color(green) legend(pos(10) ring(0) col(1)) 

***************************************************************************************************************************************************************************************



*ESTIMATE LOCAL PROJECTIONS MODEL (LINEAR CASE)

xtset statenr time
foreach y in tdebtinc lrgdp lrhw_sa cpi{
forval i= 1/20 {
local shock "mpsg"
local xtime time_dum1-time_dum68
local lags 1 
local controls "l(1/`lags').(dtdebtinc dlrgdp dlcpi dlrhw_sa dur dlrincome_pc `shock')"
	qui xtivreg2 d`i'`y'_cum `shock' `controls' `xtime', fe dkraay(2) small
	qui replace coef_`y' =_b[`shock'] if h==`i'
	qui replace coefu_`y' =_b[`shock'] + 1.645*_se[`shock'] if h==`i'
	qui replace coefl_`y' =_b[`shock'] - 1.645*_se[`shock'] if h==`i'
}
}

*Convert IRF into a 1-std. deviation change in the MPSG
foreach y in tdebtinc lrgdp lrhw_sa cpi{
foreach w in coef coefu coefl{
	replace `w'_`y' = `w'_`y'*std_mpsg
}
}

*FIGURE 6 in the paper
set scheme s1mono
foreach y in tdebtinc lrgdp lrhw_sa cpi{
	twoway rarea coefu_`y' coefl_`y' h if h>=0 & h<=20 & statenr==1, legend(off) color(gs14) xtitle("") xlabel(0 5 10 15 20) || line coef_`y' h ///
	if h>=0 & h<=20 & statenr==1, name(`y', replace) lpattern(solid dash) color(navy) graphregion(fcolor(white)) title(`: variable label `y'')  nodraw
	local graphnames `graphnames' `y'
	}
graph combine `graphnames'


***************************************************************************************************************************************************************************************



*PURGED MPSG 

xtset statenr time
foreach y in tdebtinc lrgdp lrhw_sa cpi{
forval i= 1/20 {
local shock "mpsg_exo"
local xtime time_dum1-time_dum68
local lags 1
local controls "l(1/`lags').(dtdebtinc dlrgdp dlcpi dlrhw_sa dur dlrincome_pc `shock')"
	qui xtivreg2 d`i'`y'_cum `shock' `controls' `xtime', fe dkraay(2) small
	qui replace coef_`y' =_b[`shock'] if h==`i'
	qui replace coefu_`y' =_b[`shock'] + 1.645*_se[`shock'] if h==`i'
	qui replace coefl_`y' =_b[`shock'] - 1.645*_se[`shock'] if h==`i'
	}
}

*1-std deviation change
sum mpsg_exo if tin(1999q1,2017q4)
gen std_mpsg_exo=r(sd)

*Convert IRF into a 1-std. deviation change in the MPSG
foreach y in tdebtinc lrtdebt lrgdp lrhw_sa cpi{
foreach w in coef coefu coefl{
	replace `w'_`y' = `w'_`y'*std_mpsg_exo
}
}

*FIGURE B.14 in the appendix
set scheme s1mono
foreach y in tdebtinc lrgdp lrhw_sa cpi{
	twoway rarea coefu_`y' coefl_`y' h if h>=0 & h<=20 & statenr==1, legend(off) color(gs14) xtitle("") xlabel(0 5 10 15 20) || line coef_`y' h ///
	if h>=0 & h<=20 & statenr==1, name(`y', replace) lpattern(solid dash) color(navy) graphregion(fcolor(white)) title(`: variable label `y'')  nodraw
	local graphnames `graphnames' `y'
	}
graph combine `graphnames'

***************************************************************************************************************************************************************************************




*CONSUMPTION (LINEAR CASE)

xtset statenr time 
foreach y in lrpce lrpce_dur lrpce_ndur lrpce_serv {
forval i= 1/20 {
local xtime time_dum1-time_dum68
local shock "mpsg"
local lags 1
local controls "l(1/`lags').(d.`y' dtdebtinc dlcpi dlrhw_sa dur dlrincome_pc `shock')"
	qui xtivreg2 d`i'`y'_cum `shock' `controls', fe dkraay(2) small
	qui replace coef_`y' =_b[`shock'] if h==`i'
	qui replace coefu_`y' =_b[`shock'] + 1.645*_se[`shock'] if h==`i'
	qui replace coefl_`y' =_b[`shock'] - 1.645*_se[`shock'] if h==`i'
}
}

*Convert IRF into a 1-std. deviation change in the MPSG
foreach y in lrpce lrpce_dur lrpce_ndur lrpce_serv {
foreach w in coef coefu coefl{
	replace `w'_`y' = `w'_`y'*std_mpsg
}
}

*FIGURE B.15 in the appendix
set scheme s1mono
foreach y in lrpce lrpce_dur lrpce_ndur lrpce_serv{
	twoway rarea coefu_`y' coefl_`y' h if h>=0 & h<=20 & statenr==1, legend(off) color(gs14) xtitle("") xlabel(0 5 10 15 20) || line coef_`y' h ///
	if h>=0 & h<=20 & statenr==1, name(`y', replace) lpattern(solid dash) color(navy) graphregion(fcolor(white)) title(`: variable label `y'')  nodraw
	local graphnames `graphnames' `y'
	}
graph combine `graphnames'


************************************************************************************************************************************************************************************



*ESTIMATE LOCAL PROJECTIONS MODEL (HIGH VS LOW DEBT PERIODS)

xtset statenr time 
qui foreach y in tdebtinc lrgdp lrhw_sa cpi {
qui forval i= 1/20 {
local shock "mpsg"
local xtime time_dum1-time_dum68
local lags 4
local controls_h "l(1/`lags').(dtdebtinc_debt_h d.lrgdp_debt_h dlcpi_debt_h dlrhw_sa_debt_h dur_debt_h dlrincome_pc_debt_h `shock' `shock'_debt_h)"
local controls_l "l(1/`lags').(dtdebtinc_debt_l d.lrgdp_debt_l dlcpi_debt_l dlrhw_sa_debt_l dur_debt_l dlrincome_pc_debt_l `shock'_debt_l)"
local controls_m "l(1/`lags').(dtdebtinc_debt_m d.lrgdp_debt_m dlcpi_debt_m dlrhw_sa_debt_m dur_debt_m dlrincome_pc_debt_m `shock'_debt_m)"
local debt "debt_h debt_l"
	qui xtivreg2 d`i'`y'_cum `shock'_debt_m `shock'_debt_h `shock'_debt_l `controls_m' `controls_h' `controls_l' `debt' `xtime', fe dkraay(2) small 
	qui replace coef_`y'_debt_m =_b[`shock'_debt_m] if h==`i'
	qui replace coefu_`y'_debt_m =_b[`shock'_debt_m] + 1.645*_se[`shock'_debt_m] if h==`i'
	qui replace coefl_`y'_debt_m =_b[`shock'_debt_m] - 1.645*_se[`shock'_debt_m] if h==`i'

	qui replace coef_`y'_debt_h =_b[`shock'_debt_h] if h==`i'
	qui replace coefu_`y'_debt_h =_b[`shock'_debt_h] + 1.645*_se[`shock'_debt_h] if h==`i'
	qui replace coefl_`y'_debt_h =_b[`shock'_debt_h] - 1.645*_se[`shock'_debt_h] if h==`i'

	qui replace coef_`y'_debt_l =_b[`shock'_debt_l] if h==`i'
	qui replace coefu_`y'_debt_l =_b[`shock'_debt_l] + 1.645*_se[`shock'_debt_l] if h==`i'
	qui replace coefl_`y'_debt_l =_b[`shock'_debt_l] - 1.645*_se[`shock'_debt_l] if h==`i'
}
}

*Convert IRF into a 1-std. deviation change in the MPSG
foreach w in coef coefu coefl{
foreach y in tdebtinc lrgdp lrhw_sa cpi{
foreach debt in debt_h debt_l debt_m { 
	replace `w'_`y'_`debt' = `w'_`y'_`debt'*std_mpsg
}
}
}

*FIGURE 7 in the paper
set scheme s1mono
foreach y in tdebtinc lrgdp lrhw_sa cpi{
	twoway line coef_`y'_debt_m coef_`y'_debt_h coef_`y'_debt_l h if h>=0 & h<=20 & statenr==5, nodraw legend(off) yline(0) xtitle("") xlabel(0 5 10 15 20) ///
	lpattern(solid longdash dash) color(navy cranberry green) graphregion(fcolor(white)) ytitle(`: variable label `y'') name(`y', replace)
	local `y'1 ``y'' `y'
	}
graph combine `tdebtinc1' `lrgdp1' `lrhw_sa1' `cpi1', cols(1) xsize(2) ysize(7) name(combine1, replace) title("3 debt states", size(medsmall)) nodraw

foreach y in tdebtinc lrgdp lrhw_sa cpi{
	twoway rarea coefu_`y'_debt_h coefl_`y'_debt_h h if h>=0 & h<=20 & statenr==1, nodraw legend(off) color(gs14) xtitle("") xlabel(0 5 10 15 20) ///
	|| line coef_`y'_debt_h h if h>=0 & h<=20 & statenr==1, name(`y', replace) lpattern(solid dash) color(navy) graphregion(fcolor(white))
	local `y'2 ``y'' `y'
	}
graph combine `tdebtinc2' `lrgdp2' `lrhw_sa2' `cpi2', cols(1) xsize(2) ysize(7) name(combine2, replace) title("High debt", size(medsmall)) nodraw

foreach y in tdebtinc lrgdp lrhw_sa cpi{
	twoway rarea coefu_`y'_debt_l coefl_`y'_debt_l h if h>=0 & h<=20 & statenr==1, nodraw legend(off) color(gs14) xtitle("") xlabel(0 5 10 15 20) ///
	|| line coef_`y'_debt_l h if h>=0 & h<=20 & statenr==1, name(`y', replace) lpattern(solid dash) color(navy) graphregion(fcolor(white)) 
	local `y'3 ``y'' `y'
	}
graph combine `tdebtinc3' `lrgdp3' `lrhw_sa3' `cpi3', cols(1) xsize(2) ysize(7) name(combine3, replace) title("Low debt", size(medsmall)) nodraw 

graph combine combine1 combine2 combine3, cols(3) xsize(3) ysize(3) name(combine_final, replace)

************************************************************************************************************************************************************************************



*CONSUMPTION (HIGH VS LOW DEBT PERIODS)

xtset statenr time 
foreach y in lrpce lrpce_dur lrpce_ndur lrpce_serv {
forval i= 1/20 {
local xtime time_dum1-time_dum68
local shock "mpsg"
local lags 1
local controls_h "l(1/`lags').(d.`y'_debt_h dtdebtinc_debt_h dlcpi_debt_h dlrhw_sa_debt_h dur_debt_h dlrincome_pc_debt_h `shock'_debt_h)"
local controls_l "l(1/`lags').(d.`y'_debt_l dtdebtinc_debt_l dlcpi_debt_l dlrhw_sa_debt_l dur_debt_l dlrincome_pc_debt_l `shock'_debt_l)"
local controls_m "l(1/`lags').(d.`y'_debt_m dtdebtinc_debt_m dlcpi_debt_m dlrhw_sa_debt_m dur_debt_m dlrincome_pc_debt_m `shock'_debt_m)"
local debt "debt_h debt_l"
	qui xtivreg2 d`i'`y'_cum `shock'_debt_m `shock'_debt_h `shock'_debt_l `controls_m' `controls_h' `controls_l' `debt', fe dkraay(2) small
	qui replace coef_`y'_debt_m =_b[`shock'_debt_m] if h==`i'
	qui replace coefu_`y'_debt_m =_b[`shock'_debt_m] + 1.645*_se[`shock'_debt_m] if h==`i'
	qui replace coefl_`y'_debt_m =_b[`shock'_debt_m] - 1.645*_se[`shock'_debt_m] if h==`i'

	qui replace coef_`y'_debt_h =_b[`shock'_debt_h] if h==`i'
	qui replace coefu_`y'_debt_h =_b[`shock'_debt_h] + 1.645*_se[`shock'_debt_h] if h==`i'
	qui replace coefl_`y'_debt_h =_b[`shock'_debt_h] - 1.645*_se[`shock'_debt_h] if h==`i'

	qui replace coef_`y'_debt_l =_b[`shock'_debt_l] if h==`i'
	qui replace coefu_`y'_debt_l =_b[`shock'_debt_l] + 1.645*_se[`shock'_debt_l] if h==`i'
	qui replace coefl_`y'_debt_l =_b[`shock'_debt_l] - 1.645*_se[`shock'_debt_l] if h==`i'
	}
}

*Convert IRF into a 1-std. deviation change in the MPSG
foreach w in coef coefu coefl{
foreach y in lrpce lrpce_dur lrpce_ndur lrpce_serv {
foreach debt in debt_h debt_l debt_m { 
	replace `w'_`y'_`debt' = `w'_`y'_`debt'*std_mpsg
}
}
}

*FIGURE B.17 in the appendix
foreach y in lrpce lrpce_dur lrpce_ndur lrpce_serv {
	twoway line coef_`y'_debt_m coef_`y'_debt_h coef_`y'_debt_l h if h>=0 & h<=20 & statenr==5, nodraw legend(off) yline(0) xtitle("") xlabel(0 5 10 15 20) lpattern(solid longdash dash) color(navy cranberry green) ///
	graphregion(fcolor(white)) ytitle(`: variable label `y'') name(`y', replace)
	local `y'1 ``y'' `y'
	}
graph combine `lrpce1' `lrpce_dur1' `lrpce_ndur1' `lrpce_serv1', cols(1) xsize(2) ysize(7) name(combine1, replace) title("3 debt states", size(medsmall)) nodraw

foreach y in lrpce lrpce_dur lrpce_ndur lrpce_serv {
	twoway rarea coefu_`y'_debt_h coefl_`y'_debt_h h if h>=0 & h<=20 & statenr==1, nodraw legend(off) color(gs14) xtitle("") xlabel(0 5 10 15 20) || line coef_`y'_debt_h h if h>=0 & h<=20 & statenr==1, name(`y', replace) ///
	lpattern(solid dash) color(navy) graphregion(fcolor(white))
	local `y'2 ``y'' `y'
	}
graph combine `lrpce2' `lrpce_dur2' `lrpce_ndur2' `lrpce_serv2', cols(1) xsize(2) ysize(7) name(combine2, replace) title("High debt", size(medsmall)) nodraw

foreach y in lrpce lrpce_dur lrpce_ndur lrpce_serv {
	twoway rarea coefu_`y'_debt_l coefl_`y'_debt_l h if h>=0 & h<=20 & statenr==1, nodraw legend(off) color(gs14) xtitle("") xlabel(0 5 10 15 20) || line coef_`y'_debt_l h if h>=0 & h<=20 & statenr==1, name(`y', replace) ///
	lpattern(solid dash) color(navy) graphregion(fcolor(white)) 
	local `y'3 ``y'' `y'
	}
graph combine `lrpce3' `lrpce_dur3' `lrpce_ndur3' `lrpce_serv3', cols(1) xsize(2) ysize(7) name(combine3, replace) title("Low debt", size(medsmall)) nodraw 

graph combine combine1 combine2 combine3, cols(3) xsize(3) ysize(3) name(combine_final, replace)


************************************************************************************************************************************************************************************



*EXTENSIVE AND INTENSIVE MARGINS OF THE HOUSING MARKET

xtset statenr time 
qui foreach y in homeown_sa lrhpi_sa{
qui forval i= 1/20 {
local shock "mpsg"
local xtime time_dum1-time_dum68
local lags 1 
local controls_h "l(1/`lags').(dtdebtinc_debt_h d.lrgdp_debt_h dlcpi_debt_h dhomeown_sa_debt_h dlrhpi_sa_debt_h dur_debt_h dlrincome_pc_debt_h `shock' `shock'_debt_h)"
local controls_l "l(1/`lags').(dtdebtinc_debt_l d.lrgdp_debt_l dlcpi_debt_l dhomeown_sa_debt_l dlrhpi_sa_debt_l dur_debt_l dlrincome_pc_debt_l `shock'_debt_l)"
local controls_m "l(1/`lags').(dtdebtinc_debt_m d.lrgdp_debt_m dlcpi_debt_m dhomeown_sa_debt_m dlrhpi_sa_debt_m dur_debt_m dlrincome_pc_debt_m `shock'_debt_m)"
local debt "debt_h debt_l"
	qui xtivreg2 d`i'`y'_cum `shock'_debt_m `shock'_debt_h `shock'_debt_l `controls_m' `controls_h' `controls_l' `debt' `xtime', fe dkraay(2) small 
	qui replace coef_`y'_debt_m =_b[`shock'_debt_m] if h==`i'
	qui replace coefu_`y'_debt_m =_b[`shock'_debt_m] + 1.645*_se[`shock'_debt_m] if h==`i'
	qui replace coefl_`y'_debt_m =_b[`shock'_debt_m] - 1.645*_se[`shock'_debt_m] if h==`i'

	qui replace coef_`y'_debt_h =_b[`shock'_debt_h] if h==`i'
	qui replace coefu_`y'_debt_h =_b[`shock'_debt_h] + 1.645*_se[`shock'_debt_h] if h==`i'
	qui replace coefl_`y'_debt_h =_b[`shock'_debt_h] - 1.645*_se[`shock'_debt_h] if h==`i'

	qui replace coef_`y'_debt_l =_b[`shock'_debt_l] if h==`i'
	qui replace coefu_`y'_debt_l =_b[`shock'_debt_l] + 1.645*_se[`shock'_debt_l] if h==`i'
	qui replace coefl_`y'_debt_l =_b[`shock'_debt_l] - 1.645*_se[`shock'_debt_l] if h==`i'
}
}

*Convert IRF into a 1-std. deviation change in the MPSG
foreach w in coef coefu coefl{
foreach y in homeown_sa lrhpi_sa{
foreach debt in debt_h debt_l debt_m { 
	replace `w'_`y'_`debt' = `w'_`y'_`debt'*std_mpsg
}
}
}

*FIGURE B.18 in the appendix
set scheme s1mono
foreach y in homeown_sa lrhpi_sa{
	twoway line coef_`y'_debt_h coef_`y'_debt_l h if h>=0 & h<=20 & statenr==5, nodraw legend(off) yline(0) xtitle("") xlabel(0 5 10 15 20) ///
	lpattern(longdash dash) color(cranberry green) graphregion(fcolor(white)) ytitle(`: variable label `y'') name(`y', replace)
	local `y'1 ``y'' `y'
	}
graph combine `homeown_sa1' `lrhpi_sa1', cols(1) xsize(6) ysize(5) name(combine1, replace) title("3 debt states", size(medsmall)) nodraw

foreach y in homeown_sa lrhpi_sa{
	twoway rarea coefu_`y'_debt_h coefl_`y'_debt_h h if h>=0 & h<=20 & statenr==1, nodraw legend(off) color(gs14) xtitle("") xlabel(0 5 10 15 20) ///
	|| line coef_`y'_debt_h h if h>=0 & h<=20 & statenr==1, name(`y', replace) lpattern(solid dash) color(navy) graphregion(fcolor(white))
	local `y'2 ``y'' `y'
	}
graph combine `homeown_sa2' `lrhpi_sa2', cols(1) xsize(6) ysize(5) name(combine2, replace) title("High debt", size(medsmall)) nodraw

foreach y in homeown_sa lrhpi_sa{
	twoway rarea coefu_`y'_debt_l coefl_`y'_debt_l h if h>=0 & h<=20 & statenr==1, nodraw legend(off) color(gs14) xtitle("") xlabel(0 5 10 15 20) ///
	|| line coef_`y'_debt_l h if h>=0 & h<=20 & statenr==1, name(`y', replace) lpattern(solid dash) color(navy) graphregion(fcolor(white)) 
	local `y'3 ``y'' `y'
	}
graph combine `homeown_sa3' `lrhpi_sa3', cols(1) xsize(6) ysize(5) name(combine3, replace) title("Low debt", size(medsmall)) nodraw 

graph combine combine1 combine2 combine3, cols(3) name(combine_final, replace)


************************************************************************************************************************************************************************************



*REGIONAL ASYMMETRIES: IMPLIED IRF FOR THE US STATES

gen mpsg_tdebtinc_gap = mpsg*tdebtinc_gap

foreach y in lrgdp lrhw_sa cpi{
foreach w in coef coefl coefu{
	gen `w'_`y'_gap =.
}
}

xtset statenr time
foreach y in tdebtinc lrgdp lrhw_sa cpi{
forval i= 1/20 {
local shock "mpsg"
local xtime time_dum1-time_dum68
local lags 1
local controls "l(1/`lags').(dtdebtinc dlrgdp dlcpi dlrhw_sa dur dlrincome_pc `shock')"
local dum "tdebtinc_gap"
	qui xtivreg2 d`i'`y'_cum `shock' `shock'_tdebtinc_gap `controls' `xtime' `dum', fe dkraay(2) small
	qui replace coef_`y' =_b[`shock'] if h==`i'
	qui replace coefu_`y' =_b[`shock'] + 1.645*_se[`shock'] if h==`i'
	qui replace coefl_`y' =_b[`shock'] - 1.645*_se[`shock'] if h==`i'

	qui replace coef_`y'_gap =_b[`shock'_tdebtinc_gap] if h==`i'
	qui replace coefu_`y'_gap =_b[`shock'_tdebtinc_gap] + 1.645*_se[`shock'_tdebtinc_gap] if h==`i'
	qui replace coefl_`y'_gap =_b[`shock'_tdebtinc_gap] - 1.645*_se[`shock'_tdebtinc_gap] if h==`i'
	}
}

*Evaluate IRF for states by taking the debt gap at a given point in time
sum time
local lo=167
local hi=r(max)
forv i=`lo'/`hi' {
local yy=year(dofq(`i'))
local qq=quarter(dofq(`i'))
	gen tdebtinc_gap`yy'q`qq' = .
	gen tdebtinc_gap_avg`yy'q`qq' = .
}

sum time
local lo=167
local hi=r(max)
forv i=`lo'/`hi' {
foreach z in tdebtinc lrgdp lrhw_sa cpi{
foreach w in coef coefu coefl{
local yy=year(dofq(`i'))
local qq=quarter(dofq(`i'))
	gen `w'_`z'`yy'q`qq' = .
	gen `w'_`z'_avg`yy'q`qq' = .
}
}
}

*Average state
sum time
local lo=167
local hi=r(max)
forv i=`lo'/`hi' {
local yy=year(dofq(`i'))
local qq=quarter(dofq(`i'))
	capture sum tdebtinc_gap if time==`i'
	capture replace tdebtinc_gap_avg`yy'q`qq' = r(mean)
}

*Individual state
sum time
local lo=167
local hi=r(max)
forval j=1/50{
forv i=`lo'/`hi' {
local yy=year(dofq(`i'))
local qq=quarter(dofq(`i'))
	capture sum tdebtinc_gap if statenr==`j' & time==`i'
	capture replace tdebtinc_gap`yy'q`qq' = r(mean) if statenr==`j'
}
}

*Multiply by coefficient
sum time
local lo=167
local hi=r(max)
forval j=1/50{
forv i=`lo'/`hi' {
local yy=year(dofq(`i'))
local qq=quarter(dofq(`i'))
foreach z in tdebtinc lrgdp lrhw_sa cpi{
foreach w in coef coefu coefl{
	capture replace `w'_`z'`yy'q`qq' = `w'_`z'_gap*(tdebtinc_gap`yy'q`qq'-tdebtinc_gap_avg`yy'q`qq') if statenr==`j'
	capture replace `w'_`z'_avg`yy'q`qq' = `w'_`z'_gap*tdebtinc_gap_avg`yy'q`qq'
}
}
}
}

*Dispersion of debt gaps over time
bys time: egen tdebtinc_gap_iqr=iqr(tdebtinc_gap)

xtset statenr time
gen tdebtinc_gap_iqr4q = (F1.tdebtinc_gap_iqr + tdebtinc_gap_iqr + L1.tdebtinc_gap_iqr + L2.tdebtinc_gap_iqr) / 4

*FIGURE B.20 in the appendix
set scheme s1mono
twoway line tdebtinc_gap_iqr4q time if tin(2002q4,2017q4) & statenr==1, legend(off) ytitle(percentage points) yla(2(1)7) xtitle("") xla(169(10)231) graphregion(fcolor(white)) color(navy) name(dispersion, replace) 


*FIGURE 8 in the paper
local time1 "2008q1"
xtline coef_tdebtinc`time1' coef_lrhw_sa`time1' if h>=0 & h<=20, addplot(line coef_lrgdp`time1' h if h>=0 & h<=20, color(cranberry) lpattern(longdash) yaxis(2)) yline(0) ///
byopts(rescale note(" ")) i(state) t(h) ytitle(" ") xtitle(" ") legend(label(1 "Debt-to-income") label(2 "Housing wealth") label(3 "GDP (rhs)") ) color(navy green) ///
lpattern(solid dash_dot) legend(size(vsmall) rows(1)) graphregion(fcolor(white))


************************************************************************************************************************************************************************************



*STATE-SPECIFIC RECESSIONS AND HIGH VS LOW DEBT PERIODS (COMBINED EFFECTS)


xtset statenr time 
foreach y in tdebtinc lrgdp lrhw_sa cpi{
forval i= 1/20 {
local xtime time_dum1-time_dum68
local recess "gdpma_r ogap_r"
local nber: word 1 of `recess' /*change here the recession variable, 1: Figure 9 or 2: Figure B.21 */
local shock "mpsg"
local xtime time_dum1-time_dum68
local lags 4 /*Change lag structure*/
local controls_h "l(1/`lags').(dtdebtinc_debt_h d.lrgdp_debt_h dlcpi_debt_h dlrhw_sa_debt_h dur_debt_h dlrincome_pc_debt_h `shock' `shock'_debt_h)"
local controls_l "l(1/`lags').(dtdebtinc_debt_l d.lrgdp_debt_l dlcpi_debt_l dlrhw_sa_debt_l dur_debt_l dlrincome_pc_debt_l `shock'_debt_l)"
local controls_m "l(1/`lags').(dtdebtinc_debt_m d.lrgdp_debt_m dlcpi_debt_m dlrhw_sa_debt_m dur_debt_m dlrincome_pc_debt_m `shock'_debt_m)"
local controls_nber_h "l(1/`lags').(dtdebtinc_`nber'_debt_h d.lrgdp_`nber'_debt_h dlcpi_`nber'_debt_h dlrhw_sa_`nber'_debt_h dur_`nber'_debt_h dlrincome_pc_`nber'_debt_h `shock'_`nber'_debt_h)"
local controls_nber_l "l(1/`lags').(dtdebtinc_`nber'_debt_l d.lrgdp_`nber'_debt_l dlcpi_`nber'_debt_l dlrhw_sa_`nber'_debt_l dur_`nber'_debt_l dlrincome_pc_`nber'_debt_l `shock'_`nber'_debt_l)"
local controls_nber_m "l(1/`lags').(dtdebtinc_`nber'_debt_m d.lrgdp_`nber'_debt_m dlcpi_`nber'_debt_m dlrhw_sa_`nber'_debt_m dur_`nber'_debt_m dlrincome_pc_`nber'_debt_m `shock'_`nber'_debt_m)"
local debt "debt_h debt_l"
	qui xtivreg2 d`i'`y'_cum `shock'_debt_m `shock'_debt_h `shock'_debt_l `shock'_`nber'_debt_m `shock'_`nber'_debt_h `shock'_`nber'_debt_l `controls_m' `controls_h' `controls_l' ///
	`controls_nber_m' `controls_nber_h' `controls_nber_l' `nber' `debt' `xtime', fe dkraay(2) small

	/*High debt states in Recessions*/
	qui lincom `shock'_debt_h + `shock'_`nber'_debt_h
	qui replace coef_`y'_`nber'_debt_h =r(estimate) if h==`i'
	qui replace coefu_`y'_`nber'_debt_h =coef_`y'_`nber'_debt_h + 1.645*r(se) if h==`i'
	qui replace coefl_`y'_`nber'_debt_h =coef_`y'_`nber'_debt_h - 1.645*r(se) if h==`i'

	/*Low debt states in Recessions*/
	qui lincom `shock'_debt_l + `shock'_`nber'_debt_l
	qui replace coef_`y'_`nber'_debt_l =r(estimate) if h==`i'
	qui replace coefu_`y'_`nber'_debt_l =coef_`y'_`nber'_debt_l + 1.645*r(se) if h==`i'
	qui replace coefl_`y'_`nber'_debt_l =coef_`y'_`nber'_debt_l - 1.645*r(se) if h==`i'
	
	/*Other states in Recessions*/
	qui lincom `shock'_debt_m + `shock'_`nber'_debt_m
	qui replace coef_`y'_`nber'_debt_m =r(estimate) if h==`i'
	qui replace coefu_`y'_`nber'_debt_m =coef_`y'_`nber'_debt_m + 1.645*r(se) if h==`i'
	qui replace coefl_`y'_`nber'_debt_m =coef_`y'_`nber'_debt_m - 1.645*r(se) if h==`i'

	/*High debt states in Expansions*/
	qui replace coef_`y'_debt_h =_b[`shock'_debt_h] if h==`i'
	qui replace coefu_`y'_debt_h =_b[`shock'_debt_h] + 1.645*_se[`shock'_debt_h] if h==`i'
	qui replace coefl_`y'_debt_h =_b[`shock'_debt_h] - 1.645*_se[`shock'_debt_h] if h==`i'

	/*Low debt states in Expansions*/
	qui replace coef_`y'_debt_l =_b[`shock'_debt_l] if h==`i'
	qui replace coefu_`y'_debt_l =_b[`shock'_debt_l] + 1.645*_se[`shock'_debt_l] if h==`i'
	qui replace coefl_`y'_debt_l =_b[`shock'_debt_l] - 1.645*_se[`shock'_debt_l] if h==`i'
	
	/*Other states in Expansions*/
	qui replace coef_`y'_debt_m =_b[`shock'_debt_m] if h==`i'
	qui replace coefu_`y'_debt_m =_b[`shock'_debt_m] + 1.645*_se[`shock'_debt_m] if h==`i'
	qui replace coefl_`y'_debt_m =_b[`shock'_debt_m] - 1.645*_se[`shock'_debt_m] if h==`i'
}
}

*Convert IRF into a 1-std. deviation change in the MPSG
foreach w in coef coefu coefl{
foreach y in tdebtinc lrgdp lrhw_sa cpi{
foreach debt in debt_h debt_l debt_m { 
	replace `w'_`y'_`debt' = `w'_`y'_`debt'*std_mpsg
}
}
}
foreach w in coef coefu coefl{
foreach y in tdebtinc lrgdp lrhw_sa cpi{
foreach debt in debt_h debt_l debt_m{ 
foreach recess in gdpma_r ogap_r {
	replace `w'_`y'_`recess'_`debt' = `w'_`y'_`recess'_`debt'*std_mpsg
}
}
}
}

*FIGURE 9 in the paper
foreach y in tdebtinc lrgdp lrhw_sa cpi{
local recess "gdpma_r ogap_r"
local nber: word 1 of `recess' /*change here the recession variable, 1: Figure 9 or 2: Figure B.21*/
	twoway line coef_`y'_debt_h coef_`y'_`nber'_debt_h coef_`y'_debt_l coef_`y'_`nber'_debt_l h if h>=0 & h<=20 & statenr==1, legend(off) yline(0) xtitle(" ") lpattern(solid dash solid dash) ///
	color(cranberry cranberry green green) graphregion(fcolor(white)) ytitle(`: variable label `y'') name(`y', replace) nodraw
	local `y'1 ``y'' `y'
	}
graph combine `tdebtinc1' `lrgdp1' `lrhw_sa1' `cpi1', cols(1) xsize(2) ysize(7) name(combine1, replace) title("All", size(medsmall)) nodraw

foreach y in tdebtinc lrgdp lrhw_sa cpi{
local recess "gdpma_r ogap_r"
local nber: word 1 of `recess' /*change here the recession variable, 1: Figure 9 or 2: Figure B.21*/
	twoway rarea coefu_`y'_debt_h coefl_`y'_debt_h h if h>=0 & h<=20 & statenr==1, xtitle(" ") legend(off) color(gs14) || line coef_`y'_debt_h h if h>=0 & h<=20 & statenr==1, ///
	lpattern(solid) color(navy) || line  coef_`y'_`nber'_debt_h coefu_`y'_`nber'_debt_h coefl_`y'_`nber'_debt_h h if h>=0 & h<=20 & statenr==1, lpattern(solid dash dash) ///
	color(cranberry cranberry cranberry) graphregion(fcolor(white)) name(`y', replace) nodraw
	local `y'2 ``y'' `y'
	}
graph combine `tdebtinc2' `lrgdp2' `lrhw_sa2' `cpi2', cols(1) xsize(2) ysize(7) name(combine2, replace) title("High debt", size(medsmall)) nodraw

foreach y in tdebtinc lrgdp lrhw_sa cpi{
local recess "gdpma_r gdp_r ogap_r ugap_r"
local nber: word 3 of `recess' /*change here the recession variable, 1: Figure 9 or 2: Figure B.21*/
	twoway rarea coefu_`y'_debt_l coefl_`y'_debt_l h if h>=0 & h<=20 & statenr==1, xtitle(" ") legend(off) color(gs14) || line coef_`y'_debt_l h if h>=0 & h<=20 & statenr==1, ///
	lpattern(solid) color(navy) || line  coef_`y'_`nber'_debt_l coefu_`y'_`nber'_debt_l coefl_`y'_`nber'_debt_l h if h>=0 & h<=20 & statenr==1, lpattern(solid dash dash) ///
	color(cranberry cranberry cranberry) graphregion(fcolor(white)) name(`y', replace) nodraw
	local `y'3 ``y'' `y'
	}
graph combine `tdebtinc3' `lrgdp3' `lrhw_sa3' `cpi3', cols(1) xsize(2) ysize(7) name(combine3, replace) title("Low debt", size(medsmall)) nodraw

graph combine combine1 combine2 combine3, cols(3) xsize(3) ysize(3) name(combine_final, replace)


***************************************************************************************************************************************************************************************



