
*LOCAL PROJECTIONS FOR ROBUSTNESS CHECKS


label variable tdebtinc "Debt-to-income"
label variable lrgdp "GDP"
label variable hpinc_sa "House prices"
label variable lrhpi_sa "House prices"
label variable lrhw_sa "Housing wealth"
label variable homeown_sa "Homeownership rate"
label variable cpi "Inflation"
label variable lrpce "PCE"
label variable lrpce_dur "PCE: durables"
label variable lrpce_ndur "PCE: non-durables"
label variable lrpce_serv "PCE: services"
label variable lrpce_dsv "PCE: dur. & serv."

bysort statenr: gen dtdebtinc_gap = d.tdebtinc_gap

*h is the horizon
bysort statenr (time): gen h = _n-95 if time>=tq(1999q3)
sum h

foreach v in coef coefu coefl{
foreach p in tdebtinc tdebtinc_gap lrtdebt lrgdp lrgdp_pc lrpce lrpce_dur lrpce_ndur lrpce_serv lrpce_dsv hpinc_sa lrhpi_sa lrhw_sa cpi mpsg homeown_sa{
	gen `v'_`p' =.
}
}

*Cumulative growth
foreach v in tdebtinc tdebtinc_gap hpinc_sa mpsg homeown_sa{
forval i= 1/21 {
	by statenr: gen d`i'`v'_cum = F`i'.`v' - F1.`v'
}
}

foreach v in lrgdp lrgdp_pc lrpce lrpce_dur lrpce_ndur lrpce_serv lrpce_dsv lrtdebt lrhpi_sa lrhw_sa{
forval i= 1/21 {
	by statenr: gen d`i'`v'_cum = (F`i'.`v' - F1.`v')*100
}
}

forval i= 1/21 {
	by statenr: gen d`i'cpi_cum = (F`i'.lcpi-F1.lcpi)*100
}

*Rename h to be consistent with the IRF charts
foreach v in tdebtinc tdebtinc_gap hpinc_sa lrgdp lrgdp_pc lrpce lrpce_dur lrpce_ndur lrpce_serv lrpce_dsv lrtdebt lrhpi_sa lrhw_sa cpi mpsg homeown_sa{
forval i= 1/21{
local j = `i'-1
	rename d`i'`v'_cum d`j'`v'_cum
}
}

*1-std deviation change
sum mpsg if tin(1999q1,2017q4)
gen std_mpsg=r(sd)



*DEFINING HIGH VS LOW DEBT PERIODS

*Time series (quintiles)
egen debt_q = xtile(tdebtinc_gap) if tin(1999q1,2017q4), by(statenr) nq(5)
tab debt_q if time>=tq(1999q1)

*Define high vs low (lagged one period to control for endogeneity)
foreach v in h l m{
	gen debt_`v' = 0
}
replace debt_h = 1 if l1.debt_q==5
replace debt_l = 1 if l1.debt_q==1
replace debt_m = 1 if inlist(l1.debt_q,2,3,4)
tab debt_h debt_l if tin(1999q1,2017q4)
tab debt_h debt_m if tin(1999q1,2017q4)


xtset statenr time 
foreach var in lrgdp dlrgdp lrpce lrpce_dur lrpce_ndur lrpce_serv lrpce_dsv dlrpce dlrpce_dur dlrpce_ndur dlrpce_serv dlrpce_dsv tdebtinc dlrtdebt mpsg lrgdp_pc ///
hpinc_sa lrhw_sa dlrhw_sa dlcpi cpi dtdebtinc dtdebtinc_gap dlrhpi_sa dhomeown_sa dur dhpinc_sa dintrcm dltv dforecl dlrincome_pc{ 
foreach debt in debt_h debt_l debt_m { 
	gen `var'_`debt' = `var'*`debt' 
}
}

foreach v in coef coefu coefl {
foreach w in tdebtinc tdebtinc_gap lrtdebt lrgdp lrgdp_pc lrpce lrpce_dur lrpce_ndur lrpce_serv lrpce_dsv dlrpce dlrpce_dur dlrpce_ndur dlrpce_serv dlrpce_dsv hpinc_sa ///
lrhpi_sa lrhw_sa cpi mpsg homeown_sa{
foreach debt in debt_h debt_l debt_m { 
	gen `v'_`w'_`debt' =.
}
}
}


	
*RECESSIONS/SLACK

foreach r in gdpma_r gdp_r ogap_r ugap_r{
	gen `r' = 0
}

*State-specififc recession dummy - 20% of sample according to 1st quintile of 3-quarter moving average (similar to Tenreyro and Thwaites, 2016)
bysort statenr: gen dlrgdp_ma = (dlrgdp + l1.dlrgdp + l2.dlrgdp)/3 
egen dlrgdp_ma_q = xtile(dlrgdp_ma) if tin(1999q1,2017q3), by(statenr) nq(5)
tab dlrgdp_ma_q if time>=tq(1999q1)
by statenr: replace gdpma_r = 1 if l1.dlrgdp_ma_q==1 
tab gdpma_r if tin(1999q1,2017q3)
bysort gdpma_r: sum ogap_ham if tin(1999q1,2017q3)

*2 consecutive declines in real GDP
xtset statenr time 
by statenr: replace gdp_r = 1 if l1.dlrgdp<0 & l2.dlrgdp<0

*Negative output gap or positive ugap
xtset statenr time 
by statenr: replace ogap_r = 1 if ogap_ham<0
by statenr: replace ugap_r = 1 if ugap_ham>0
tab ogap_r ugap_r if tin(1999q1,2017q4)


xtset statenr time 
foreach var in lrgdp dlrgdp lrpce lrpce_dur lrpce_ndur lrpce_serv lrpce_dsv dlrpce dlrpce_dur dlrpce_ndur dlrpce_serv dlrpce_dsv tdebtinc dlrtdebt mpsg lrgdp_pc ///
hpinc_sa lrhw_sa dlrhw_sa dlcpi cpi dtdebtinc dtdebtinc_gap dlrhpi_sa dhomeown_sa { 
foreach recess in gdpma_r gdp_r ogap_r ugap_r { 
	gen `var'_`recess' = `var'*`recess' 
}
}

foreach v in coef coefu coefl {
foreach w in tdebtinc tdebtinc_gap lrtdebt lrgdp lrgdp_pc lrpce lrpce_dur lrpce_ndur lrpce_serv lrpce_dsv hpinc_sa lrhpi_sa lrhw_sa cpi homeown_sa{
foreach recess in gdpma_r gdp_r ogap_r ugap_r { 
	gen `v'_`w'_`recess' =.
}
}
}

xtset statenr time 
foreach var in lrgdp dlrgdp lrgdp_pc lrpce lrpce_dur lrpce_ndur lrpce_serv lrpce_dsv dlrpce dlrpce_dur dlrpce_ndur dlrpce_serv dlrpce_dsv tdebtinc lrtdebt mpsg ///
hpinc_sa lrhw_sa dlrhw_sa dlcpi cpi dtdebtinc dtdebtinc_gap dlrhpi_sa dhomeown_sa dur dlrincome_pc{ 
foreach debt in debt_h debt_l debt_m { 
foreach recess in gdpma_r gdp_r ogap_r ugap_r {
	gen `var'_`recess'_`debt' = `var'*`recess'*`debt'
}
}
}

foreach v in coef coefu coefl {
foreach w in tdebtinc lrtdebt lrgdp lrgdp_pc lrpce lrpce_dur lrpce_ndur lrpce_serv lrpce_dsv hpinc_sa lrhpi_sa lrhw_sa cpi homeown_sa{
foreach debt in debt_h debt_l debt_m { 
foreach recess in gdpma_r gdp_r ogap_r ugap_r {
	gen `v'_`w'_`recess'_`debt' =.
}
}
}
}

*Start estimation from 1999q1
drop if tin(1976q1,1998q4)

*For xtivreg2 I need to create the time dummies!
tabulate time, generate(time_dum)

***************************************************************************************************************************************************************************************



*ESTIMATE LOCAL PROJECTIONS MODEL (LINEAR CASE)

xtset statenr time
foreach y in tdebtinc lrgdp lrhw_sa cpi{
forval i= 1/20 {
local shock "mpsg"
local xtime time_dum1-time_dum68
local lags 1 
local controls "l(1/`lags').(dtdebtinc dlrgdp dlcpi dlrhw_sa dur dlrincome_pc `shock')"
	qui xtivreg2 d`i'`y'_cum `shock' `controls' `xtime', fe dkraay(2) small
	qui replace coef_`y' =_b[`shock'] if h==`i'
	qui replace coefu_`y' =_b[`shock'] + 1.645*_se[`shock'] if h==`i'
	qui replace coefl_`y' =_b[`shock'] - 1.645*_se[`shock'] if h==`i'
}
}

*Convert IRF into a 1-std. deviation change in the MPSG
foreach y in tdebtinc lrgdp lrhw_sa cpi{
foreach w in coef coefu coefl{
	replace `w'_`y' = `w'_`y'*std_mpsg
}
}

***************************************************************************************************************************************************************************************

*ESTIMATE LOCAL PROJECTIONS MODEL (HIGH VS LOW DEBT PERIODS)

xtset statenr time 
qui foreach y in tdebtinc lrgdp lrhw_sa cpi {
qui forval i= 1/20 {
local shock "mpsg"
local xtime time_dum1-time_dum68
local lags 1
local controls_h "l(1/`lags').(dtdebtinc_debt_h d.lrgdp_debt_h dlcpi_debt_h dlrhw_sa_debt_h dur_debt_h dlrincome_pc_debt_h `shock' `shock'_debt_h)"
local controls_l "l(1/`lags').(dtdebtinc_debt_l d.lrgdp_debt_l dlcpi_debt_l dlrhw_sa_debt_l dur_debt_l dlrincome_pc_debt_l `shock'_debt_l)"
local controls_m "l(1/`lags').(dtdebtinc_debt_m d.lrgdp_debt_m dlcpi_debt_m dlrhw_sa_debt_m dur_debt_m dlrincome_pc_debt_m `shock'_debt_m)"
local debt "debt_h debt_l"
	qui xtivreg2 d`i'`y'_cum `shock'_debt_m `shock'_debt_h `shock'_debt_l `controls_m' `controls_h' `controls_l' `debt' `xtime', fe dkraay(2) small 
	qui replace coef_`y'_debt_m =_b[`shock'_debt_m] if h==`i'
	qui replace coefu_`y'_debt_m =_b[`shock'_debt_m] + 1.645*_se[`shock'_debt_m] if h==`i'
	qui replace coefl_`y'_debt_m =_b[`shock'_debt_m] - 1.645*_se[`shock'_debt_m] if h==`i'

	qui replace coef_`y'_debt_h =_b[`shock'_debt_h] if h==`i'
	qui replace coefu_`y'_debt_h =_b[`shock'_debt_h] + 1.645*_se[`shock'_debt_h] if h==`i'
	qui replace coefl_`y'_debt_h =_b[`shock'_debt_h] - 1.645*_se[`shock'_debt_h] if h==`i'

	qui replace coef_`y'_debt_l =_b[`shock'_debt_l] if h==`i'
	qui replace coefu_`y'_debt_l =_b[`shock'_debt_l] + 1.645*_se[`shock'_debt_l] if h==`i'
	qui replace coefl_`y'_debt_l =_b[`shock'_debt_l] - 1.645*_se[`shock'_debt_l] if h==`i'
}
}

*Convert IRF into a 1-std. deviation change in the MPSG
foreach w in coef coefu coefl{
foreach y in tdebtinc lrgdp lrhw_sa cpi{
foreach debt in debt_h debt_l debt_m { 
	replace `w'_`y'_`debt' = `w'_`y'_`debt'*std_mpsg
}
}
}
