

**************************************************************
***************** OTHER FIGURES AND TABLES *******************
**************************************************************


*FIGURE 1 in the paper
clear
use States_data
foreach v in tdebtinc dlrhw_sa ur dlrgdp dhomeown_sa{
	bysort time: egen `v'_max_ = max(`v')
	bysort time: egen `v'_min_ = min(`v')	
	bysort time: egen `v'_med_ = median(`v')	
	bysort time: egen `v'_mean_ = mean(`v')
	}

label variable tdebtinc "Debt-to-income"
label variable dlrgdp "GDP growth"
label variable dlrhw_sa "Housing wealth growth"
label variable ur "UR"

set scheme s1mono
foreach v in dlrgdp {
	twoway rarea `v'_max `v'_min time if tin(1999q1,2017q4), legend(off) color(gs14) ytitle("%") xtitle(" ") yla(-8(4)12) xla(156(15)231) ///
	|| line `v'_mean time if tin(1999q1,2017q4), lpattern(solid) color(navy) graphregion(fcolor(white)) title(`: variable label `v'') name(`v', replace) nodraw
	local `v' ``v'' `v'
	}
foreach v in ur {
	twoway rarea `v'_max `v'_min time if tin(1999q1,2017q4), legend(off) color(gs14) ytitle("%") xtitle(" ") yla(0(3)15) xla(156(15)231) ///
	|| line `v'_mean time if tin(1999q1,2017q4), lpattern(solid) color(navy) graphregion(fcolor(white)) title(`: variable label `v'') name(`v', replace) nodraw
	local `v' ``v'' `v'
	}
foreach v in tdebtinc {
	twoway rarea `v'_max `v'_min time if tin(1999q1,2017q4), legend(off) color(gs14) ytitle("%") xtitle(" ") yla(40(30)160) xla(156(15)231) ///
	|| line `v'_mean time if tin(1999q1,2017q4), lpattern(solid) color(navy) graphregion(fcolor(white)) title(`: variable label `v'') name(`v', replace) nodraw
	local `v' ``v'' `v'
	}
foreach v in dlrhw_sa{
	twoway rarea `v'_max `v'_min time if tin(1999q1,2017q4), legend(off) color(gs14) ytitle("%") xtitle(" ") yla(-12(6)12) xla(156(15)231) ///
	|| line `v'_mean time if tin(1999q1,2017q4), lpattern(solid) color(navy) graphregion(fcolor(white)) title(`: variable label `v'') name(`v', replace) nodraw
	local `v' ``v'' `v'
	}
graph combine `dlrgdp' `ur' `tdebtinc' `dlrhw_sa'

***************************************************************************************************************************************************************


*FIGURE 3 in the paper
clear
insheet using "state_agg_cpi.txt"
format time %tq
tsset time

twoway line state_cpi us_cpi time if tin(1984q1,2017q4), yline(0) lpattern(solid dash) title("") legend(label(1 "State-level CPI") label(2 "US CPI")) ///
legend(pos(1) ring(0) col(1)) color(navy cranberry) legend(size(normal) rows(1)) ytitle(%) xtitle("") xla(97(19)231) graphregion(fcolor(white)) 


***************************************************************************************************************************************************************


**********************************
*** PRINT REGRESSION TABLES ******
**********************************

clear
use US_data

foreach v in tdebt mdebt{
	gen US_`v'inc = US_`v'/US_income*100
}
	
*New method by Hamilton (2018, RESTAT)
*Hamilton suggests h=20 for the debt cycle if the data are reasonably long
foreach v in US_tdebtinc US_mdebtinc{
	reg f20.`v' l(0/3).`v', robust 
	predict yfit, xb
	predict e, resid
	gen trend_`v'_ham = l20.yfit 
	gen cycle_`v'_ham = l20.e
	drop yfit e
}

*One-sided filter (backward-looking)
foreach v in US_tdebtinc US_mdebtinc{
	tsfilter hp hp_`v'= `v' in 1/30, trend(trend_`v') smooth(400000) 
	tempvar tmp tmp2
	count
	forv i = 31/`=r(N)' {
		qui {
		tsfilter hp `tmp'=`v' in 1/`i', trend(`tmp2') smooth(400000) 
		replace hp_`v' = `tmp' in `i'
		replace trend_`v'  = `tmp2' in `i'
		drop `tmp' `tmp2'
		}
	}
}

*Figure B.22 in the appendix
set scheme s1mono
twoway line trend_US_tdebtinc_ham trend_US_tdebtinc US_tdebtinc time if tin(1984q1,2017q4), yline(0) legend(label(1 "Hamilton method") label(2 "HP filter") label(3 "Data")) ///
legend(pos(11) ring(0) col(1)) color(navy cranberry green) lpattern(solid shortdash longdash) ytitle(% of personal income) xtitle("") xlabel(96(27)231) title("Trend and actual data") name(trend, replace) nodraw
twoway line cycle_US_tdebtinc_ham hp_US_tdebtinc time if tin(1984q1,2017q4), yline(0) legend(label(1 "Hamilton method") label(2 "HP filter")) ///
legend(pos(7) ring(0) col(1)) color(navy cranberry green) lpattern(solid dash) ytitle(percentage points) xtitle("") xlabel(96(27)231) title("Gap") name(gap, replace) nodraw
graph combine trend gap, cols(2) xsize(5.5) ysize(2.5)

rename cycle_US_tdebtinc_ham US_tdebtinc_gap 


*TABLE 1 in the paper
*Baseline
newey intr l(1/1).intr US_cpi_favg US_og0 US_grgdp0 if tin(1984q1,2007q4), lag(2)
outreg2 using Robust_reg.xls, bdec(3) stats(coef se) onecol label ctitle("Base") replace
*Wu-Xia
newey wu_xia l(1/1).wu_xia cpi_favg_greenspf og_greenspf grgdp_greenspf if tin(1984q1,2017q4), lag(2)
outreg2 using Robust_reg.xls, bdec(3) stats(coef se) onecol label ctitle("Wu-Xia") append
*Financial cycle
newey wu_xia l(1/1).wu_xia cpi_favg_greenspf og_greenspf grgdp_greenspf US_tdebtinc_gap if tin(1984q1,2017q4), lag(2)
outreg2 using Robust_reg.xls, bdec(3) stats(coef se) onecol label ctitle("Finan.") append
*Ugap
newey intr l(1/1).intr US_cpi_favg US_ugap0 US_grgdp0 if tin(1984q1,2007q4), lag(2)
outreg2 using Robust_reg.xls, bdec(3) stats(coef se) onecol label ctitle("Ugap") append
*Actual data
newey intr l(1/1).intr US_cpi_yoy US_ugap if tin(1984q1,2007q4), lag(2)
outreg2 using Robust_reg.xls, bdec(3) stats(coef se) onecol label ctitle("No expec.") append

*Get the R2
reg intr l(1/1).intr US_cpi_favg US_og0 US_grgdp0 if tin(1984q1,2007q4), robust
display e(r2_a)
reg wu_xia l(1/1).wu_xia cpi_favg_greenspf og_greenspf grgdp_greenspf if tin(1984q1,2017q4), robust
display e(r2_a)
reg wu_xia l(1/1).wu_xia cpi_favg_greenspf og_greenspf grgdp_greenspf US_tdebtinc_gap if tin(1984q1,2017q4), robust
display e(r2_a)
reg intr l(1/1).intr US_cpi_favg US_ugap0 US_grgdp0 if tin(1984q1,2007q4), robust
display e(r2_a)
reg intr l(1/1).intr US_cpi_yoy US_ugap if tin(1984q1,2007q4), robust
display e(r2_a)

***************************************************************************************************************************************************************


*SUMMARY STATISTICS
 
*TABLE A.1 in the appendix (run after Estimate_Taylor.do for the benchmark)
xtset statenr time
sum mpsg cpi_yoy tdebtinc lrgdp lrincome_pc lrincome_pc lrhw_sa lrhpi_sa homeown_sa lrpce lrpce_dur lrpce_ndur lrpce_serv ur if tin(1999q1,2017q2)
sum d.mpsg d.cpi_yoy dtdebtinc dlrgdp dlrincome_pc dlrhw_sa dlrhpi_sa dhomeown_sa dlrpce dlrpce_dur dlrpce_ndur dlrpce_serv d.ur if tin(1999q1,2017q2)


*FIGURE B.13: MPSG BY STATE
set scheme s1mono
xtline mpsg if tin(1999q4,2017q2), byopts(rescale note(" ")) i(state) t(time) ytitle(" ") xtitle(" ") xla(159(35)229) color(navy) lpattern(solid)

***************************************************************************************************************************************************************

*******************************************************************
*** TIME OF DELEVERAGING AND DECLINE IN GDP AND HOUSE PRICES ******
*******************************************************************

clear
use US_data
tsset time

foreach v in tdebt mdebt{
	gen US_`v'inc = US_`v'/US_income*100
}

gen US_rhpi = US_hpi/US_cpi*100
gen US_rtdebt = US_tdebt/US_cpi*100

*Convert to indices (2002q1=100)
foreach v in US_rgdp US_rhpi US_tdebtinc US_tdebtinc_nyfed US_rtdebt {
	gen `v'_base=.
	sum `v' if time==tq(2002q1)
	local temp=r(mean)
	replace `v'_base=`v'*100/`temp'
}

*FIGURE B.19 in the appendix
gen nber=160 if tin(2008q1,2009q1)
lab var nber "NBER recessions"
twoway (area nber time if tin(2002q1,2017q4), bcolor(gs12)) (line US_rgdp_base US_rhpi_base US_tdebtinc_nyfed_base time if tin(2002q1,2017q4), xla(168(9)231) ///
legend(order(2 "Real GDP" 3 "Real house prices" 4 "Debt-to-income")) legend(size(small) pos(7) ring(0) col(1)) color(navy cranberry green) lpattern(solid longdash shortdash) ///
ytitle(Index) xtitle(""))

***************************************************************************************************************************************************************


*********************************************************
***** CPI proxy vs Implicit Regional Price Deflator *****
*********************************************************

clear
use States_data
xtset statenr time

*FIGURE 2 IN ONLINE APPENDIX
set scheme s1mono
xtline cpi_yoy if tin(1984q1,2017q4), byopts(rescale note(" ")) i(state) t(time) ytitle(" ") xtitle(" ") xla(97(67)231) ///
legend(off) color(navy) graphregion(fcolor(white))


*Compute annual CPI
bysort statenr year: egen cpi_year = mean(cpi)

*Drop duplicates
bysort year statenr:  gen dup = cond(_N==1,0,_n)
sum if dup>1
drop if dup>1
keep if year>=2008 & year<=2015
keep year state statenr cpi_year

*Merge datasets
merge 1:1 year state using States_irpd,
drop _merge
xtset statenr year

*% annual inflation and 2009-15 average inflation
foreach v in cpi_year irpd{
	by statenr: gen d`v' = (`v'/l1.`v')*100-100
}

foreach v in cpi_year irpd{
	bysort statenr: egen avg_d`v' = mean(d`v') if year>=2009 & year<=2015
}
bysort statenr: gen davg = avg_dcpi_year - avg_dirpd
bysort statenr: gen davg_abs = abs(davg)
egen corr_cpi = corr(dcpi_year dirpd), by(statenr)

*Merge with income coverage by state
merge m:1 state using States_inc_cov, assert(match master) keep(match master)
drop _merge


*FIGURE 3 IN ONLINE APPENDIX
set scheme s1mono
xtline dcpi_year dirpd if year>=2009 & year<=2015, byopts(rescale note(" ")) i(state) t(year) ytitle(" ") xtitle(" ") xla(2009(2)2015) legend(label(1 "CPI") label(2 "IRPD (BEA)")) ///
legend(off) color(navy cranberry) lpattern(solid dash) legend(size(vsmall) rows(1)) graphregion(fcolor(white))


*FIGURE 4 IN ONLINE APPENDIX
set scheme s1mono
twoway (lfit inc_cov davg_abs if year==2015, color(black)) (scatter inc_cov davg_abs if year==2015, mlabel(state) mcolor(navy)), xtitle("Absolute dif. between 2009-15 average CPI inflation and IRPD") ///
ytitle("State coverage by MSA data (% of personal income)") legend(off) graphregion(fcolor(white))

*TABLE 1 IN ONLINE APPENDIX
tabstat corr_cpi avg_dcpi_year avg_dirpd davg if year==2015, s(mean) by(state) format(%9.2f)


***************************************************************************************************************************************************************
